'''
Author: 饕餮
Date: 2022-01-21 10:38:17
version: 
LastEditors: 饕餮
LastEditTime: 2022-01-21 11:30:42
Description: file content
'''
'''
Author: 饕餮
Date: 2021-11-17 12:01:47
version: 
LastEditors: 饕餮
LastEditTime: 2022-01-21 09:30:05
Description: file content
'''
import json
import base64
import requests
import datetime
class HunterApi:
    def __init__(self,username,apikey):
        self.url = "https://hunter.qianxin.com/openApi/search"
        self.username = username
        self.apikey = apikey
    def GetData(self,query_str,page=1,page_size=10,days=30):
        nowTime = datetime.datetime.now()
        requestData = {
            "search":base64.urlsafe_b64encode(query_str.encode("utf-8")).decode(),
            "page":page,
            "page_size":page_size,
            "is_web":"1",
            "end_time":nowTime.strftime("%Y-%m-%d"),
            "start_time":(nowTime - datetime.timedelta(days=days)).strftime("%Y-%m-%d"),
            "username":self.username,
            "api-key":self.apikey
        }
        headerData = {
            "Content-Type": "application/json",
        }
        rep = requests.get(self.url,params=requestData,headers=headerData)
        return json.loads(rep.text)




'''
Author: 饕餮
Date: 2022-01-21 10:37:56
version: 
LastEditors: 饕餮
LastEditTime: 2022-01-21 15:37:17
Description: file content
'''
import json
from hunter_sdk.Common.HunterObject import HunterObject
from hunter_sdk.HunterApi import HunterApi

class Hunter:
    def __init__(self,configPath='config.json',keyName='Hunter'):
        with open(configPath, 'r') as config_f:
            Config = json.load(config_f)
            HunterConfig = Config[keyName]
            _username = HunterConfig["username"]
            _apikey = HunterConfig["apikey"]
            self.hunterApi = HunterApi(_username,_apikey)

    def Search(self,queryStr,page=1,page_size=10,days=30):
        responseData = self.hunterApi.GetData(queryStr,page,page_size,days)
        hunterObject = HunterObject(responseData)
        self.NowPage = page
        self._usePageSize = page_size
        self._useQuery = queryStr
        self._useDays = days
        self.TotalPage = int(hunterObject.Total / 10)
        if self.TotalPage > 10000: 
            self.TotalPage = 10000
        return hunterObject

    def Next(self,page_number=1):
        page = self.NowPage + page_number
        if page > self.TotalPage: page = self.TotalPage
        return self.Search(self._useQuery,page,self._usePageSize,self._useDays)

    def Last(self,page_number=1):
        page = self.NowPage - page_number
        if page < 1: page = 1
        return self.Search(self._useQuery,page,self._usePageSize,self._useDays)


import json
class BaseObject:
    def __init__(self):
        self.ObjectData = {}

    def TryGetValue(self,key,default=None):
        keyArray = key.split('.')
        keyStr = ""
        #key内容为字典的不存在则返回默认
        if len(keyArray) > 0:
            baseDic = self.ObjectData
            for k in keyArray[0:len(keyArray)]:
                if k not in baseDic.keys():
                    return default
                baseDic = baseDic[k]
        #key栈组装
        for k in keyArray:
            keyStr +="['{0}']".format(k)
        #数据赋值
        return eval("self.ObjectData" + keyStr)

    def SetValue(self,key,value):
        keyArray = key.split('.')
        keyStr = ""
        #key内容为字典的不存在则建立
        if len(keyArray) > 1:
            baseDic = self.ObjectData
            for k in keyArray[0:len(keyArray)-1]:
                if k not in baseDic.keys():
                    baseDic[k] = {}
                baseDic = baseDic[k]
        #key栈组装
        for k in keyArray:
            keyStr +="['{0}']".format(k)
        #数据赋值
        exec("self.ObjectData" + keyStr + "=value")

    def is_json(self,jsonStr):
        try:
            json_object = json.loads(jsonStr)
        except ValueError as e:
            return False
        return True


'''
Author: 饕餮
Date: 2021-12-23 21:23:03
version: 
LastEditors: 饕餮
LastEditTime: 2022-01-21 11:35:47
Description: setup
'''
from __future__ import print_function
from setuptools import setup,find_packages
import sys

setup(
    name="hunter_sdk",
    version="0.0.9",
    author="spensercai",
    author_email="spensercai@gmail.com",
    description="Hunter SDK",
    long_description="Hunter SDK",
    license="MIT",
    url="https://github.com/SpenserCai/Hunter-SDK",
    packages=find_packages(),
    include_package_data=True,
    classifiers=[

    ],
    install_requires=[

    ],
    zip_safe=True,

)


'''
Author: 饕餮
Date: 2021-11-17 13:53:52
version: 
LastEditors: 饕餮
LastEditTime: 2022-01-21 12:03:17
Description: file content
'''
from typing import List
from hunter_sdk.Common.BaseObject import *

class HunterListItem(BaseObject):
    def __init__(self,jsonData={}):
        self.ObjectData = jsonData

    @property
    def IsRisk(self):
        return self.TryGetValue("is_risk")

    @property
    def Url(self):
        return self.TryGetValue("url")

    @property
    def Ip(self):
        return self.TryGetValue("ip")

    @property
    def Port(self):
        return self.TryGetValue("port")

    @property
    def WebTitle(self):
        return self.TryGetValue("web_title")

    @property
    def Domain(self):
        return self.TryGetValue("domain")

    @property
    def IsRiskProtocol(self):
        return self.TryGetValue("is_risk_protocol")

    @property
    def Protocol(self):
        return self.TryGetValue("protocol")

    @property
    def BaseProtocol(self):
        return self.TryGetValue("base_protocol")

    @property
    def StatusCode(self):
        return self.TryGetValue("status_code")

    @property
    def Component(self):
        return self.TryGetValue("component")

    @property
    def Os(self):
        return self.TryGetValue("os")

    @property
    def Company(self):
        return self.TryGetValue("company")

    @property
    def Number(self):
        return self.TryGetValue("number")

    @property
    def Country(self):
        return self.TryGetValue("country")

    @property
    def Province(self):
        return self.TryGetValue("province")

    @property
    def City(self):
        return self.TryGetValue("city")

    @property
    def UpdatedAt(self):
        return self.TryGetValue("updated_at")

    @property
    def IsWeb(self):
        return self.TryGetValue("is_web")

    @property
    def AsOrg(self):
        return self.TryGetValue("as_org")

    @property
    def Isp(self):
        return self.TryGetValue("isp")

class HunterObject(BaseObject):
    def __init__(self, jsonData):
        self.ObjectData = jsonData

    @property
    def Code(self):
        return self.TryGetValue("code",0)

    @property
    def Message(self):
        return self.TryGetValue("message","")

    @property
    def Total(self):
        return self.TryGetValue("data.total",0)

    @property
    def TotalPage(self):
        return self.TryGetValue("data.total_page",0)

    @property
    def StartTime(self):
        return self.TryGetValue("data.start_time")

    @property
    def EndTime(self):
        return self.TryGetValue("data.end_time")

    @property
    def IsWeb(self):
        return self.TryGetValue("data.is_web")

    @property
    def HunterList(self) -> List[HunterListItem]:
        returnList = []
        tmpList = self.TryGetValue("data.arr")
        for item in tmpList:
            listItem = HunterListItem(item)
            returnList.append(listItem)
        return returnList